pycocoa.colors.RGBColor

Package pycocoa :: Module colors :: Class RGBColor |
[frames] | no frames]

# Class RGBColor

              object --+
                       |
    internals._Objectype --+
                           |
            baseTypes._Type0 --+
                               |
                           Color --+
                                   |
                                  RGBColor

Color in the Red-Green-Blue space.

Instance Methods
Inherited from `Color`: `__init__`, `copy`, `toCMY3`, `toHSB3`, `toRGB3` Inherited from `baseTypes._Type0`: `__repr__`, `__str__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| blue Get the blue component (`float`) or `None` if not applicable.
| green Get the green component (`float`) or `None` if not applicable.
| red Get the red component (`float`) or `None` if not applicable.
Inherited from `Color`: `alpha`, `black`, `brightness`, `colorSpace`, `cyan`, `hex`, `hue`, `magenta`, `n`, `name`, `nsColor`, `saturation`, `white`, `yellow` Inherited from `baseTypes._Type0`: `NS`, `NSDelegate` Inherited from `internals._Objectype`: `typename` Inherited from `object`: `__class__`

Property Details

### blue Get the blue component (`float`) or `None` if not applicable. Get Method: blue(self) - Get the blue component (`float`) or `None` if not applicable. Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.

### green Get the green component (`float`) or `None` if not applicable. Get Method: green(self) - Get the green component (`float`) or `None` if not applicable. Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.

### red Get the red component (`float`) or `None` if not applicable. Get Method: red(self) - Get the red component (`float`) or `None` if not applicable. Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.